import 'dart:io';

import 'package:args/command_runner.dart';

import '../core/cli_message_printer.dart';
import '../core/process_runner.dart';

class CreateCommand extends Command<void> {
  @override
  String get name => 'create';

  @override
  String get description =>
      'Sets up a new Dawn application in the current directory.';

  @override
  String get invocation => 'dawn create <app_name>';

  String get _appName => argResults!.rest.first;

  @override
  void run() {
    if (argResults!.rest.isEmpty) {
      usageException('Specify your application\'s name.\n');
    }

    final directory = Directory('./$_appName');

    if (directory.existsSync()) {
      usageException('Directory $_appName already exists.\n');
    }

    Directory.current = directory..createSync();

    _createFiles();
    _installDependencies();

    printCliMessage('Enjoy Coding!', type: CliMessageType.success);

    printCliMessage(
      'Run the following commands:\n'
      '  cd $_appName\n'
      '  webdev serve',
    );
  }

  void _createFiles() {
    printCliMessage('Creating Files...');

    _createFile(path: './.gitignore', body: _gitIgnore);
    _createFile(path: './README.md', body: _readmeDotMd);
    _createFile(path: './pubspec.yaml', body: _pubspecDotYaml);
    _createFile(path: './analysis_options.yaml', body: _analysisOptionsDotYaml);
    _createFile(path: './web/index.html', body: _indexDotHtml);
    _createFile(path: './web/main.dart', body: _mainDotDart);
    _createFile(path: './web/assets/logo.svg', body: _logoDotSvg);
    _createFile(path: './web/assets/icon.svg', body: _iconDotSvg);
    _createFile(path: './web/assets/title.svg', body: _titleDotSvg);
    _createFile(path: './web/assets/banner.svg', body: _bannerDotSvg);
  }

  void _createFile({
    required final String path,
    required final String body,
  }) {
    File(path)
      ..createSync(recursive: true)
      ..writeAsStringSync(body);

    printCliMessage(
      'Created $path.',
      listItem: true,
      type: CliMessageType.success,
    );
  }

  void _installDependencies() {
    printCliMessage('Installing dependencies...');

    _installDependency('dawn');
    _installDependency('dawn_lints', dev: true);
    _installDependency('build_runner', dev: true);
    _installDependency('build_web_compilers', dev: true);
  }

  void _installDependency(final String name, {final bool dev = false}) {
    runProcess(
      'dart',
      ['pub', 'add', if (dev) '-d', name],
      throwOnError: false,
      onSuccess: () => printCliMessage(
        'Installed $name.',
        listItem: true,
        type: CliMessageType.success,
      ),
      onError: () => printCliMessage(
        'Couldn\'t install $name.',
        listItem: true,
        type: CliMessageType.error,
      ),
    );
  }

  String get _gitIgnore => '''
# Files and directories created by pub.
.dart_tool/
.packages

# Conventional directory for build output.
build/
''';

  String get _readmeDotMd => '''
<img
    src="https://raw.githubusercontent.com/Hawmex/dawn/main/example/web/assets/banner.svg"
    width="100%"
/>

---

# $_appName

A Dawn App.

[ [Visit Dawn's official website →](https://dawn-dev.netlify.app) ]

## Serve Your App

```
webdev serve
```

[ [Read more →](https://dawn-dev.netlify.app/get-started) ]

''';

  String get _pubspecDotYaml => '''
name: $_appName
description: A Dawn app
publish_to: none
environment:
  sdk: ">=2.18.0 <3.0.0"
''';

  String get _analysisOptionsDotYaml => '''
include: package:dawn_lints/dawn_lints.yaml
''';

  String get _indexDotHtml => '''
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />

    <title>$_appName</title>

    <link rel="shortcut icon" href="/assets/icon.svg" type="image/x-icon" />

    <style>
      *,
      *::before,
      *::after {
        margin: 0px;
        padding: 0px;
        -webkit-tap-highlight-color: transparent;
        box-sizing: border-box;
      }
    </style>

    <script src="/main.dart.js" defer></script>
  </head>

  <body></body>
</html>
''';

  String get _mainDotDart => '''
import 'package:dawn/dawn.dart';

void main() => runApp(const App());

class App extends StatelessWidget {
  const App({super.key});

  @override
  Widget build(final BuildContext context) {
    return const Container(
      [
        Image(
          '/assets/logo.svg',
          style: Style({'width': '128px', 'height': '128px'}),
          animation: Animation(
            keyframes: [
              Keyframe(
                offset: 0,
                style: Style({'transform': 'translateY(0px)'}),
              ),
              Keyframe(
                offset: 1,
                style: Style({'transform': 'translateY(8px)'}),
              ),
            ],
            duration: Duration(seconds: 1),
            easing: Easing(0.2, 0, 0.4, 1),
            direction: AnimationDirection.alternate,
            iterations: double.infinity,
          ),
        ),
        Text(
          'Welcome to Dawn',
          style: Style({
            'font-size': '24px',
            'font-weight': 'bold',
            'color': '#00e690',
          }),
        ),
        Container([
          Text('To get started, edit '),
          Text(
            'web/main.dart',
            style: Style({
              'font-family': 'monospace',
              'background': '#eeeeee',
              'border-radius': '4px',
              'padding': '4px',
            }),
          ),
          Text(' and save to reload.'),
        ]),
      ],
      style: Style({
        'display': 'flex',
        'flex-flow': 'column',
        'justify-content': 'center',
        'text-align': 'center',
        'align-items': 'center',
        'gap': '16px',
        'padding': '16px',
        'width': '100%',
        'min-height': '100vh',
        'background': '#ffffff',
        'color': '#000000',
        'font-family': '"Jost", system-ui',
        'user-select': 'none',
      }),
    );
  }
}
''';

  String get _logoDotSvg => '''
<svg width="128" height="128" viewBox="0 0 128 128" fill="none" xmlns="http://www.w3.org/2000/svg">
    <g clip-path="url(#clip0_3_11)">
        <path d="M60.2426 12.7279C57.8995 10.3848 57.8995 6.58578 60.2426 4.24263V4.24263C62.5858 1.89949 66.3848 1.89949 68.7279 4.24263L123.882 59.397C126.225 61.7401 126.225 65.5391 123.882 67.8822L119.64 72.1249L60.2426 12.7279Z" fill="#7900EA" />
        <path d="M59.397 4.24264C61.7401 1.89949 65.5391 1.89949 67.8823 4.24264V4.24264C70.2254 6.58579 70.2254 10.3848 67.8823 12.7279L8.48528 72.1249L4.24264 67.8822C1.8995 65.5391 1.8995 61.7401 4.24264 59.397L59.397 4.24264Z" fill="#7900EA" />
        <rect x="58" y="25" width="12" height="46" rx="6" fill="#7900EA" />
        <rect x="86" y="101" width="12" height="12" rx="6" fill="#7900EA" />
        <rect x="58" y="74" width="12" height="24" rx="6" fill="#7900EA" />
        <rect x="30" y="101" width="12" height="24" rx="6" fill="#7900EA" />
        <rect x="30" y="53" width="12" height="45" rx="6" fill="#7900EA" />
        <rect x="86" y="53" width="12" height="45" rx="6" fill="#7900EA" />
    </g>
    <defs>
        <clipPath id="clip0_3_11">
            <rect width="128" height="128" fill="white" />
        </clipPath>
    </defs>
</svg>
''';

  String get _iconDotSvg => '''
<svg width="128" height="128" viewBox="0 0 128 128" fill="none" xmlns="http://www.w3.org/2000/svg">
    <rect width="128" height="128" rx="56" fill="white" />
    <path d="M61.1379 26.5366C59.3823 24.781 59.3823 21.9345 61.1379 20.1789V20.1789C62.8936 18.4232 65.7401 18.4232 67.4957 20.1789L107.757 60.4405C110.101 62.7837 110.101 66.5827 107.757 68.9258L105.642 71.0409L61.1379 26.5366Z" fill="#7900EA" />
    <path d="M60.5043 20.1789C62.2599 18.4232 65.1064 18.4232 66.8621 20.1789V20.1789C68.6177 21.9345 68.6177 24.781 66.8621 26.5366L22.3578 71.0409L20.2426 68.9258C17.8995 66.5827 17.8995 62.7837 20.2426 60.4405L60.5043 20.1789Z" fill="#7900EA" />
    <rect x="59.4576" y="35.7317" width="8.99123" height="34.4664" rx="4.49561" fill="#7900EA" />
    <rect x="80.4371" y="92.6762" width="8.99123" height="8.99123" rx="4.49561" fill="#7900EA" />
    <rect x="59.4576" y="72.4459" width="8.99123" height="17.9825" rx="4.49561" fill="#7900EA" />
    <rect x="38.4781" y="92.6762" width="8.99123" height="17.9825" rx="4.49561" fill="#7900EA" />
    <rect x="38.4781" y="56.7113" width="8.99123" height="33.7171" rx="4.49561" fill="#7900EA" />
    <rect x="80.4371" y="56.7113" width="8.99123" height="33.7171" rx="4.49561" fill="#7900EA" />
</svg>
''';

  String get _titleDotSvg => '''
<svg width="167" height="180" viewBox="0 0 167 180" fill="none" xmlns="http://www.w3.org/2000/svg">
    <g clip-path="url(#clip0_3_40)">
        <path d="M79.2426 12.7279C76.8995 10.3848 76.8995 6.58578 79.2426 4.24263V4.24263C81.5858 1.89949 85.3848 1.89949 87.7279 4.24263L142.882 59.397C145.225 61.7401 145.225 65.5391 142.882 67.8822L138.64 72.1249L79.2426 12.7279Z" fill="#7900EA" />
        <path d="M78.397 4.24264C80.7401 1.89949 84.5391 1.89949 86.8823 4.24264V4.24264C89.2254 6.58579 89.2254 10.3848 86.8823 12.7279L27.4853 72.1249L23.2426 67.8822C20.8995 65.5391 20.8995 61.7401 23.2426 59.397L78.397 4.24264Z" fill="#7900EA" />
        <rect x="77" y="25" width="12" height="46" rx="6" fill="#7900EA" />
        <rect x="105" y="101" width="12" height="12" rx="6" fill="#7900EA" />
        <rect x="77" y="74" width="12" height="24" rx="6" fill="#7900EA" />
        <rect x="49" y="101" width="12" height="24" rx="6" fill="#7900EA" />
        <rect x="49" y="53" width="12" height="45" rx="6" fill="#7900EA" />
        <rect x="105" y="53" width="12" height="45" rx="6" fill="#7900EA" />
    </g>
    <path d="M4.9235 131.2V176H16.0595V131.2H4.9235ZM20.9235 176C25.8302 176 30.0755 175.083 33.6595 173.248C37.2435 171.413 40.0168 168.832 41.9795 165.504C43.9422 162.133 44.9235 158.165 44.9235 153.6C44.9235 148.992 43.9422 145.024 41.9795 141.696C40.0168 138.368 37.2435 135.787 33.6595 133.952C30.0755 132.117 25.8302 131.2 20.9235 131.2H12.0915V140.8H20.5395C22.2462 140.8 23.8888 141.013 25.4675 141.44C27.0888 141.867 28.4968 142.571 29.6915 143.552C30.9288 144.533 31.9102 145.856 32.6355 147.52C33.3608 149.141 33.7235 151.168 33.7235 153.6C33.7235 156.032 33.3608 158.08 32.6355 159.744C31.9102 161.365 30.9288 162.667 29.6915 163.648C28.4968 164.629 27.0888 165.333 25.4675 165.76C23.8888 166.187 22.2462 166.4 20.5395 166.4H12.0915V176H20.9235ZM58.389 166.784C58.389 166.059 58.5597 165.461 58.901 164.992C59.2423 164.48 59.7543 164.096 60.437 163.84C61.1197 163.584 62.037 163.456 63.189 163.456C64.6823 163.456 66.0903 163.669 67.413 164.096C68.7783 164.48 69.973 165.056 70.997 165.824V161.536C70.485 160.981 69.717 160.448 68.693 159.936C67.669 159.424 66.4317 158.997 64.981 158.656C63.573 158.315 61.973 158.144 60.181 158.144C56.5117 158.144 53.6743 158.976 51.669 160.64C49.6637 162.261 48.661 164.48 48.661 167.296C48.661 169.301 49.1303 171.008 50.069 172.416C51.0503 173.824 52.3303 174.891 53.909 175.616C55.5303 176.299 57.2797 176.64 59.157 176.64C61.0343 176.64 62.7837 176.32 64.405 175.68C66.0263 174.997 67.349 174.016 68.373 172.736C69.397 171.413 69.909 169.813 69.909 167.936L68.885 164.096C68.885 165.461 68.5863 166.613 67.989 167.552C67.3917 168.491 66.6237 169.195 65.685 169.664C64.7463 170.133 63.7223 170.368 62.613 170.368C61.845 170.368 61.141 170.24 60.501 169.984C59.861 169.685 59.349 169.28 58.965 168.768C58.581 168.213 58.389 167.552 58.389 166.784ZM54.101 155.584C54.5277 155.328 55.2103 155.008 56.149 154.624C57.0877 154.197 58.1757 153.835 59.413 153.536C60.693 153.237 61.9943 153.088 63.317 153.088C64.213 153.088 65.0023 153.173 65.685 153.344C66.4103 153.515 67.0077 153.792 67.477 154.176C67.9463 154.56 68.2877 155.029 68.501 155.584C68.757 156.096 68.885 156.715 68.885 157.44V176H78.165V155.264C78.165 153.216 77.5677 151.488 76.373 150.08C75.1783 148.672 73.557 147.605 71.509 146.88C69.461 146.112 67.1357 145.728 64.533 145.728C61.7597 145.728 59.1997 146.091 56.853 146.816C54.5063 147.541 52.501 148.309 50.837 149.12L54.101 155.584ZM80.8645 146.56L96.0325 177.856L105.569 160.32L115.297 177.856L130.465 146.56H120.353L114.208 161.664L105.569 144.32L97.1205 161.664L90.9765 146.56H80.8645ZM152.912 158.08V176H162.96V157.056C162.96 153.515 162.128 150.763 160.464 148.8C158.8 146.837 156.133 145.856 152.464 145.856C150.288 145.856 148.453 146.304 146.96 147.2C145.509 148.096 144.357 149.355 143.504 150.976V146.56H133.776V176H143.504V158.08C143.504 156.928 143.717 155.947 144.144 155.136C144.571 154.325 145.168 153.707 145.936 153.28C146.704 152.853 147.6 152.64 148.624 152.64C150.16 152.64 151.248 153.109 151.888 154.048C152.571 154.987 152.912 156.331 152.912 158.08Z" fill="#00E690" />
    <defs>
        <clipPath id="clip0_3_40">
            <rect width="128" height="128" fill="white" transform="translate(19)" />
        </clipPath>
    </defs>
</svg>
''';

  String get _bannerDotSvg => '''
<svg width="720" height="360" viewBox="0 0 720 360" fill="none" xmlns="http://www.w3.org/2000/svg">
    <rect width="720" height="360" fill="white" />
    <path d="M340.568 142.4V176H348.92V142.4H340.568ZM352.568 176C356.248 176 359.432 175.312 362.12 173.936C364.808 172.56 366.888 170.624 368.36 168.128C369.832 165.6 370.568 162.624 370.568 159.2C370.568 155.744 369.832 152.768 368.36 150.272C366.888 147.776 364.808 145.84 362.12 144.464C359.432 143.088 356.248 142.4 352.568 142.4H345.944V149.6H352.28C353.56 149.6 354.792 149.76 355.976 150.08C357.192 150.4 358.248 150.928 359.144 151.664C360.072 152.4 360.808 153.392 361.352 154.64C361.896 155.856 362.168 157.376 362.168 159.2C362.168 161.024 361.896 162.56 361.352 163.808C360.808 165.024 360.072 166 359.144 166.736C358.248 167.472 357.192 168 355.976 168.32C354.792 168.64 353.56 168.8 352.28 168.8H345.944V176H352.568ZM380.667 169.088C380.667 168.544 380.795 168.096 381.051 167.744C381.307 167.36 381.691 167.072 382.203 166.88C382.715 166.688 383.403 166.592 384.267 166.592C385.387 166.592 386.443 166.752 387.435 167.072C388.459 167.36 389.355 167.792 390.123 168.368V165.152C389.739 164.736 389.163 164.336 388.395 163.952C387.627 163.568 386.699 163.248 385.611 162.992C384.555 162.736 383.355 162.608 382.011 162.608C379.259 162.608 377.131 163.232 375.627 164.48C374.123 165.696 373.371 167.36 373.371 169.472C373.371 170.976 373.723 172.256 374.427 173.312C375.163 174.368 376.123 175.168 377.307 175.712C378.523 176.224 379.835 176.48 381.243 176.48C382.651 176.48 383.963 176.24 385.179 175.76C386.395 175.248 387.387 174.512 388.155 173.552C388.923 172.56 389.307 171.36 389.307 169.952L388.539 167.072C388.539 168.096 388.315 168.96 387.867 169.664C387.419 170.368 386.843 170.896 386.139 171.248C385.435 171.6 384.667 171.776 383.835 171.776C383.259 171.776 382.731 171.68 382.251 171.488C381.771 171.264 381.387 170.96 381.099 170.576C380.811 170.16 380.667 169.664 380.667 169.088ZM377.451 160.688C377.771 160.496 378.283 160.256 378.987 159.968C379.691 159.648 380.507 159.376 381.435 159.152C382.395 158.928 383.371 158.816 384.363 158.816C385.035 158.816 385.627 158.88 386.139 159.008C386.683 159.136 387.131 159.344 387.483 159.632C387.835 159.92 388.091 160.272 388.251 160.688C388.443 161.072 388.539 161.536 388.539 162.08V176H395.499V160.448C395.499 158.912 395.051 157.616 394.155 156.56C393.259 155.504 392.043 154.704 390.507 154.16C388.971 153.584 387.227 153.296 385.275 153.296C383.195 153.296 381.275 153.568 379.515 154.112C377.755 154.656 376.251 155.232 375.003 155.84L377.451 160.688ZM397.523 153.92L408.899 177.392L416.051 164.24L423.347 177.392L434.723 153.92H427.139L422.531 165.248L416.051 152.24L409.715 165.248L405.107 153.92H397.523ZM451.559 162.56V176H459.095V161.792C459.095 159.136 458.471 157.072 457.223 155.6C455.975 154.128 453.975 153.392 451.223 153.392C449.591 153.392 448.215 153.728 447.095 154.4C446.007 155.072 445.143 156.016 444.503 157.232V153.92H437.207V176H444.503V162.56C444.503 161.696 444.663 160.96 444.983 160.352C445.303 159.744 445.751 159.28 446.327 158.96C446.903 158.64 447.575 158.48 448.343 158.48C449.495 158.48 450.311 158.832 450.791 159.536C451.303 160.24 451.559 161.248 451.559 162.56Z" fill="#00E690" />
    <path d="M287.844 133.517C286.645 132.317 286.645 130.372 287.844 129.172C289.044 127.973 290.989 127.973 292.189 129.172L318.357 155.341C320.7 157.684 320.7 161.483 318.357 163.826L318.255 163.928L287.844 133.517Z" fill="#7900EA" />
    <path d="M287.411 129.172C288.611 127.973 290.556 127.973 291.756 129.172C292.955 130.372 292.955 132.317 291.756 133.517L261.344 163.928L261.243 163.826C258.9 161.483 258.899 157.684 261.243 155.341L287.411 129.172Z" fill="#7900EA" />
    <rect x="286.696" y="139.8" width="6.144" height="23.552" rx="3.072" fill="#7900EA" />
    <rect x="301.032" y="178.712" width="6.144" height="6.144" rx="3.072" fill="#7900EA" />
    <rect x="286.696" y="164.888" width="6.144" height="12.288" rx="3.072" fill="#7900EA" />
    <rect x="272.36" y="178.712" width="6.144" height="12.288" rx="3.072" fill="#7900EA" />
    <rect x="272.36" y="154.136" width="6.144" height="23.04" rx="3.072" fill="#7900EA" />
    <rect x="301.032" y="154.136" width="6.144" height="23.04" rx="3.072" fill="#7900EA" />
    <path d="M158.523 223.648H161.667C162.835 223.648 163.859 223.488 164.739 223.168C165.635 222.832 166.339 222.352 166.851 221.728C167.379 221.104 167.643 220.352 167.643 219.472C167.643 218.512 167.379 217.72 166.851 217.096C166.339 216.456 165.635 215.984 164.739 215.68C163.859 215.36 162.835 215.2 161.667 215.2H155.499V232H162.075C163.403 232 164.555 231.84 165.531 231.52C166.507 231.184 167.259 230.672 167.787 229.984C168.331 229.296 168.603 228.392 168.603 227.272C168.603 226.424 168.411 225.704 168.027 225.112C167.659 224.504 167.163 224.008 166.539 223.624C165.915 223.224 165.219 222.936 164.451 222.76C163.683 222.584 162.891 222.496 162.075 222.496H158.523V224.704H161.619C162.019 224.704 162.379 224.744 162.699 224.824C163.035 224.888 163.331 225 163.587 225.16C163.843 225.32 164.043 225.528 164.187 225.784C164.331 226.04 164.403 226.344 164.403 226.696C164.403 227.24 164.275 227.672 164.019 227.992C163.779 228.296 163.451 228.52 163.035 228.664C162.619 228.792 162.147 228.856 161.619 228.856H159.555V218.344H161.235C161.939 218.344 162.483 218.488 162.867 218.776C163.251 219.064 163.443 219.496 163.443 220.072C163.443 220.456 163.355 220.784 163.179 221.056C163.003 221.312 162.747 221.512 162.411 221.656C162.091 221.8 161.699 221.872 161.235 221.872H158.523V223.648ZM174.868 227.68V220.96H171.076V228.064C171.076 229.376 171.388 230.408 172.012 231.16C172.652 231.896 173.66 232.264 175.036 232.264C175.852 232.264 176.532 232.096 177.076 231.76C177.62 231.408 178.06 230.936 178.396 230.344V232H182.02V220.96H178.396V227.68C178.396 228.112 178.316 228.48 178.156 228.784C177.996 229.088 177.772 229.32 177.484 229.48C177.212 229.64 176.876 229.72 176.476 229.72C175.884 229.72 175.468 229.544 175.228 229.192C174.988 228.824 174.868 228.32 174.868 227.68ZM184.665 216.808C184.665 217.384 184.873 217.856 185.289 218.224C185.705 218.592 186.201 218.776 186.777 218.776C187.369 218.776 187.865 218.592 188.265 218.224C188.681 217.856 188.889 217.384 188.889 216.808C188.889 216.232 188.681 215.768 188.265 215.416C187.865 215.048 187.369 214.864 186.777 214.864C186.201 214.864 185.705 215.048 185.289 215.416C184.873 215.768 184.665 216.232 184.665 216.808ZM185.025 220.96V232H188.529V220.96H185.025ZM191.514 213.28V232H195.162V213.28H191.514ZM206.358 213.28V232H209.982V213.28H206.358ZM197.334 226.48C197.334 227.712 197.582 228.76 198.078 229.624C198.59 230.472 199.246 231.12 200.046 231.568C200.846 232.016 201.694 232.24 202.59 232.24C203.518 232.24 204.334 232.008 205.038 231.544C205.758 231.08 206.326 230.416 206.742 229.552C207.158 228.688 207.366 227.664 207.366 226.48C207.366 225.28 207.158 224.256 206.742 223.408C206.326 222.544 205.758 221.88 205.038 221.416C204.334 220.952 203.518 220.72 202.59 220.72C201.694 220.72 200.846 220.944 200.046 221.392C199.246 221.84 198.59 222.488 198.078 223.336C197.582 224.184 197.334 225.232 197.334 226.48ZM201.15 226.48C201.15 225.904 201.27 225.408 201.51 224.992C201.75 224.56 202.07 224.232 202.47 224.008C202.87 223.768 203.31 223.648 203.79 223.648C204.206 223.648 204.606 223.76 204.99 223.984C205.39 224.208 205.718 224.536 205.974 224.968C206.23 225.384 206.358 225.888 206.358 226.48C206.358 227.072 206.23 227.584 205.974 228.016C205.718 228.432 205.39 228.752 204.99 228.976C204.606 229.2 204.206 229.312 203.79 229.312C203.31 229.312 202.87 229.2 202.47 228.976C202.07 228.736 201.75 228.408 201.51 227.992C201.27 227.56 201.15 227.056 201.15 226.48ZM223.038 218.68H230.55V215.2H223.038V218.68ZM223.038 225.256H230.31V221.992H223.038V225.256ZM220.35 215.2V232H224.238V215.2H220.35ZM235.337 228.544C235.337 228.272 235.401 228.048 235.529 227.872C235.657 227.68 235.849 227.536 236.105 227.44C236.361 227.344 236.705 227.296 237.137 227.296C237.697 227.296 238.225 227.376 238.721 227.536C239.233 227.68 239.681 227.896 240.065 228.184V226.576C239.873 226.368 239.585 226.168 239.201 225.976C238.817 225.784 238.353 225.624 237.809 225.496C237.281 225.368 236.681 225.304 236.009 225.304C234.633 225.304 233.569 225.616 232.817 226.24C232.065 226.848 231.689 227.68 231.689 228.736C231.689 229.488 231.865 230.128 232.217 230.656C232.585 231.184 233.065 231.584 233.657 231.856C234.265 232.112 234.921 232.24 235.625 232.24C236.329 232.24 236.985 232.12 237.593 231.88C238.201 231.624 238.697 231.256 239.081 230.776C239.465 230.28 239.657 229.68 239.657 228.976L239.273 227.536C239.273 228.048 239.161 228.48 238.937 228.832C238.713 229.184 238.425 229.448 238.073 229.624C237.721 229.8 237.337 229.888 236.921 229.888C236.633 229.888 236.369 229.84 236.129 229.744C235.889 229.632 235.697 229.48 235.553 229.288C235.409 229.08 235.337 228.832 235.337 228.544ZM233.729 224.344C233.889 224.248 234.145 224.128 234.497 223.984C234.849 223.824 235.257 223.688 235.721 223.576C236.201 223.464 236.689 223.408 237.185 223.408C237.521 223.408 237.817 223.44 238.073 223.504C238.345 223.568 238.569 223.672 238.745 223.816C238.921 223.96 239.049 224.136 239.129 224.344C239.225 224.536 239.273 224.768 239.273 225.04V232H242.753V224.224C242.753 223.456 242.529 222.808 242.081 222.28C241.633 221.752 241.025 221.352 240.257 221.08C239.489 220.792 238.617 220.648 237.641 220.648C236.601 220.648 235.641 220.784 234.761 221.056C233.881 221.328 233.129 221.616 232.505 221.92L233.729 224.344ZM246.067 227.992L244.555 230.392C245.051 230.776 245.587 231.128 246.163 231.448C246.739 231.752 247.363 231.992 248.035 232.168C248.723 232.36 249.467 232.456 250.267 232.456C251.579 232.456 252.595 232.16 253.315 231.568C254.051 230.96 254.419 230.064 254.419 228.88C254.419 228.192 254.267 227.64 253.963 227.224C253.675 226.808 253.283 226.464 252.787 226.192C252.307 225.92 251.779 225.68 251.203 225.472C250.659 225.264 250.195 225.096 249.811 224.968C249.443 224.824 249.155 224.672 248.947 224.512C248.755 224.352 248.659 224.152 248.659 223.912C248.659 223.704 248.739 223.536 248.899 223.408C249.075 223.28 249.331 223.216 249.667 223.216C250.163 223.216 250.707 223.36 251.299 223.648C251.891 223.92 252.419 224.272 252.883 224.704L254.179 222.352C253.747 222.032 253.283 221.752 252.787 221.512C252.307 221.272 251.787 221.08 251.227 220.936C250.683 220.792 250.091 220.72 249.451 220.72C248.651 220.72 247.939 220.84 247.315 221.08C246.707 221.32 246.219 221.672 245.851 222.136C245.499 222.6 245.323 223.168 245.323 223.84C245.323 224.544 245.475 225.12 245.779 225.568C246.083 226.016 246.467 226.376 246.931 226.648C247.411 226.904 247.915 227.128 248.443 227.32C249.035 227.496 249.499 227.664 249.835 227.824C250.187 227.984 250.435 228.152 250.579 228.328C250.723 228.488 250.795 228.688 250.795 228.928C250.795 229.184 250.707 229.392 250.531 229.552C250.355 229.712 250.083 229.792 249.715 229.792C249.459 229.792 249.155 229.744 248.803 229.648C248.451 229.536 248.043 229.352 247.579 229.096C247.131 228.824 246.627 228.456 246.067 227.992ZM255.116 220.96V223.96H262.508V220.96H255.116ZM257.06 217.12V232H260.54V217.12H257.06ZM275.184 223.072L283.32 232H287.472L278.592 222.4C277.952 221.696 277.416 221.104 276.984 220.624C276.568 220.128 276.36 219.648 276.36 219.184C276.36 218.8 276.496 218.456 276.768 218.152C277.04 217.848 277.448 217.696 277.992 217.696C278.328 217.696 278.608 217.768 278.832 217.912C279.072 218.056 279.256 218.24 279.384 218.464C279.512 218.688 279.576 218.928 279.576 219.184C279.576 219.616 279.336 220.072 278.856 220.552C278.392 221.032 277.712 221.488 276.816 221.92C276.48 222.08 276.056 222.256 275.544 222.448C275.048 222.64 274.52 222.872 273.96 223.144C273.416 223.4 272.904 223.728 272.424 224.128C271.944 224.512 271.552 224.984 271.248 225.544C270.944 226.088 270.792 226.744 270.792 227.512C270.792 228.504 271.056 229.36 271.584 230.08C272.112 230.8 272.816 231.352 273.696 231.736C274.592 232.12 275.576 232.312 276.648 232.312C277.816 232.312 278.904 232.112 279.912 231.712C280.936 231.312 281.872 230.792 282.72 230.152C283.568 229.496 284.336 228.776 285.024 227.992C285.712 227.208 286.32 226.44 286.848 225.688L284.424 223.816C283.928 224.568 283.4 225.272 282.84 225.928C282.296 226.584 281.712 227.16 281.088 227.656C280.464 228.152 279.816 228.544 279.144 228.832C278.488 229.12 277.816 229.264 277.128 229.264C276.584 229.264 276.12 229.168 275.736 228.976C275.368 228.784 275.08 228.536 274.872 228.232C274.68 227.912 274.584 227.56 274.584 227.176C274.584 226.68 274.72 226.28 274.992 225.976C275.264 225.656 275.608 225.384 276.024 225.16C276.44 224.92 276.888 224.696 277.368 224.488C277.864 224.264 278.32 224.016 278.736 223.744C279.408 223.296 280 222.896 280.512 222.544C281.024 222.176 281.456 221.816 281.808 221.464C282.16 221.096 282.424 220.712 282.6 220.312C282.776 219.896 282.864 219.408 282.864 218.848C282.864 218.176 282.68 217.536 282.312 216.928C281.944 216.304 281.4 215.792 280.68 215.392C279.96 214.992 279.072 214.792 278.016 214.792C276.96 214.792 276.04 214.992 275.256 215.392C274.488 215.792 273.896 216.312 273.48 216.952C273.064 217.592 272.856 218.256 272.856 218.944C272.856 219.52 272.968 220.04 273.192 220.504C273.432 220.968 273.728 221.416 274.08 221.848C274.448 222.264 274.816 222.672 275.184 223.072ZM296.73 215.2V226.48C296.73 227.536 296.898 228.456 297.234 229.24C297.586 230.024 298.066 230.672 298.674 231.184C299.298 231.68 300.018 232.056 300.834 232.312C301.65 232.568 302.53 232.696 303.474 232.696C304.418 232.696 305.298 232.568 306.114 232.312C306.946 232.056 307.666 231.68 308.274 231.184C308.898 230.672 309.378 230.024 309.714 229.24C310.066 228.456 310.242 227.536 310.242 226.48V215.2H306.186V226.192C306.186 227.04 305.962 227.728 305.514 228.256C305.066 228.784 304.386 229.048 303.474 229.048C302.578 229.048 301.906 228.784 301.458 228.256C301.01 227.728 300.786 227.04 300.786 226.192V215.2H296.73ZM313.918 227.992L312.406 230.392C312.902 230.776 313.438 231.128 314.014 231.448C314.59 231.752 315.214 231.992 315.886 232.168C316.574 232.36 317.318 232.456 318.118 232.456C319.43 232.456 320.446 232.16 321.166 231.568C321.902 230.96 322.27 230.064 322.27 228.88C322.27 228.192 322.118 227.64 321.814 227.224C321.526 226.808 321.134 226.464 320.638 226.192C320.158 225.92 319.63 225.68 319.054 225.472C318.51 225.264 318.046 225.096 317.662 224.968C317.294 224.824 317.006 224.672 316.798 224.512C316.606 224.352 316.51 224.152 316.51 223.912C316.51 223.704 316.59 223.536 316.75 223.408C316.926 223.28 317.182 223.216 317.518 223.216C318.014 223.216 318.558 223.36 319.15 223.648C319.742 223.92 320.27 224.272 320.734 224.704L322.03 222.352C321.598 222.032 321.134 221.752 320.638 221.512C320.158 221.272 319.638 221.08 319.078 220.936C318.534 220.792 317.942 220.72 317.302 220.72C316.502 220.72 315.79 220.84 315.166 221.08C314.558 221.32 314.07 221.672 313.702 222.136C313.35 222.6 313.174 223.168 313.174 223.84C313.174 224.544 313.326 225.12 313.63 225.568C313.934 226.016 314.318 226.376 314.782 226.648C315.262 226.904 315.766 227.128 316.294 227.32C316.886 227.496 317.35 227.664 317.686 227.824C318.038 227.984 318.286 228.152 318.43 228.328C318.574 228.488 318.646 228.688 318.646 228.928C318.646 229.184 318.558 229.392 318.382 229.552C318.206 229.712 317.934 229.792 317.566 229.792C317.31 229.792 317.006 229.744 316.654 229.648C316.302 229.536 315.894 229.352 315.43 229.096C314.982 228.824 314.478 228.456 313.918 227.992ZM329.88 232.24C331.288 232.24 332.48 231.968 333.456 231.424C334.448 230.88 335.232 230.064 335.808 228.976L332.568 228.184C332.296 228.664 331.928 229.024 331.464 229.264C331.016 229.504 330.472 229.624 329.832 229.624C329.272 229.624 328.8 229.504 328.416 229.264C328.032 229.008 327.744 228.64 327.552 228.16C327.36 227.68 327.264 227.104 327.264 226.432C327.28 225.696 327.376 225.088 327.552 224.608C327.744 224.112 328.024 223.744 328.392 223.504C328.76 223.264 329.216 223.144 329.76 223.144C330.192 223.144 330.568 223.24 330.888 223.432C331.208 223.624 331.456 223.896 331.632 224.248C331.808 224.6 331.896 225.016 331.896 225.496C331.896 225.608 331.864 225.752 331.8 225.928C331.752 226.088 331.688 226.224 331.608 226.336L332.472 225.232H325.656V227.248H335.736C335.768 227.136 335.784 227 335.784 226.84C335.784 226.664 335.784 226.488 335.784 226.312C335.784 225.128 335.552 224.12 335.088 223.288C334.624 222.456 333.952 221.824 333.072 221.392C332.192 220.944 331.112 220.72 329.832 220.72C328.552 220.72 327.44 220.952 326.496 221.416C325.568 221.88 324.856 222.544 324.36 223.408C323.864 224.272 323.616 225.296 323.616 226.48C323.616 227.648 323.872 228.664 324.384 229.528C324.896 230.392 325.616 231.064 326.544 231.544C327.488 232.008 328.6 232.24 329.88 232.24ZM341.597 220.96H338.021V232H341.597V220.96ZM344.789 224.704L346.349 221.608C346.157 221.32 345.877 221.096 345.509 220.936C345.141 220.776 344.757 220.696 344.357 220.696C343.749 220.696 343.165 220.896 342.605 221.296C342.045 221.696 341.589 222.24 341.237 222.928C340.901 223.616 340.733 224.4 340.733 225.28L341.597 226.552C341.597 226.024 341.669 225.576 341.813 225.208C341.957 224.84 342.165 224.56 342.437 224.368C342.709 224.176 343.021 224.08 343.373 224.08C343.693 224.08 343.957 224.136 344.165 224.248C344.389 224.36 344.597 224.512 344.789 224.704ZM346.593 227.872H351.681V224.728H346.593V227.872ZM356.257 218.68H363.769V215.2H356.257V218.68ZM356.257 225.256H363.529V221.992H356.257V225.256ZM353.569 215.2V232H357.457V215.2H353.569ZM369.582 220.96H366.006V232H369.582V220.96ZM372.774 224.704L374.334 221.608C374.142 221.32 373.862 221.096 373.494 220.936C373.126 220.776 372.742 220.696 372.342 220.696C371.734 220.696 371.15 220.896 370.59 221.296C370.03 221.696 369.574 222.24 369.222 222.928C368.886 223.616 368.718 224.4 368.718 225.28L369.582 226.552C369.582 226.024 369.654 225.576 369.798 225.208C369.942 224.84 370.15 224.56 370.422 224.368C370.694 224.176 371.006 224.08 371.358 224.08C371.678 224.08 371.942 224.136 372.15 224.248C372.374 224.36 372.582 224.512 372.774 224.704ZM375.657 216.808C375.657 217.384 375.865 217.856 376.281 218.224C376.697 218.592 377.193 218.776 377.769 218.776C378.361 218.776 378.857 218.592 379.257 218.224C379.673 217.856 379.881 217.384 379.881 216.808C379.881 216.232 379.673 215.768 379.257 215.416C378.857 215.048 378.361 214.864 377.769 214.864C377.193 214.864 376.697 215.048 376.281 215.416C375.865 215.768 375.657 216.232 375.657 216.808ZM376.017 220.96V232H379.521V220.96H376.017ZM388.122 232.24C389.53 232.24 390.722 231.968 391.698 231.424C392.69 230.88 393.474 230.064 394.05 228.976L390.81 228.184C390.538 228.664 390.17 229.024 389.706 229.264C389.258 229.504 388.714 229.624 388.074 229.624C387.514 229.624 387.042 229.504 386.658 229.264C386.274 229.008 385.986 228.64 385.794 228.16C385.602 227.68 385.506 227.104 385.506 226.432C385.522 225.696 385.618 225.088 385.794 224.608C385.986 224.112 386.266 223.744 386.634 223.504C387.002 223.264 387.458 223.144 388.002 223.144C388.434 223.144 388.81 223.24 389.13 223.432C389.45 223.624 389.698 223.896 389.874 224.248C390.05 224.6 390.138 225.016 390.138 225.496C390.138 225.608 390.106 225.752 390.042 225.928C389.994 226.088 389.93 226.224 389.85 226.336L390.714 225.232H383.898V227.248H393.978C394.01 227.136 394.026 227 394.026 226.84C394.026 226.664 394.026 226.488 394.026 226.312C394.026 225.128 393.794 224.12 393.33 223.288C392.866 222.456 392.194 221.824 391.314 221.392C390.434 220.944 389.354 220.72 388.074 220.72C386.794 220.72 385.682 220.952 384.738 221.416C383.81 221.88 383.098 222.544 382.602 223.408C382.106 224.272 381.858 225.296 381.858 226.48C381.858 227.648 382.114 228.664 382.626 229.528C383.138 230.392 383.858 231.064 384.786 231.544C385.73 232.008 386.842 232.24 388.122 232.24ZM403.44 225.28V232H407.208V224.896C407.208 223.568 406.896 222.536 406.272 221.8C405.648 221.064 404.648 220.696 403.272 220.696C402.456 220.696 401.768 220.864 401.208 221.2C400.664 221.536 400.232 222.008 399.912 222.616V220.96H396.264V232H399.912V225.28C399.912 224.848 399.992 224.48 400.152 224.176C400.312 223.872 400.536 223.64 400.824 223.48C401.112 223.32 401.448 223.24 401.832 223.24C402.408 223.24 402.816 223.416 403.056 223.768C403.312 224.12 403.44 224.624 403.44 225.28ZM418.444 213.28V232H422.068V213.28H418.444ZM409.42 226.48C409.42 227.712 409.668 228.76 410.164 229.624C410.676 230.472 411.332 231.12 412.132 231.568C412.932 232.016 413.78 232.24 414.676 232.24C415.604 232.24 416.42 232.008 417.124 231.544C417.844 231.08 418.412 230.416 418.828 229.552C419.244 228.688 419.452 227.664 419.452 226.48C419.452 225.28 419.244 224.256 418.828 223.408C418.412 222.544 417.844 221.88 417.124 221.416C416.42 220.952 415.604 220.72 414.676 220.72C413.78 220.72 412.932 220.944 412.132 221.392C411.332 221.84 410.676 222.488 410.164 223.336C409.668 224.184 409.42 225.232 409.42 226.48ZM413.236 226.48C413.236 225.904 413.356 225.408 413.596 224.992C413.836 224.56 414.156 224.232 414.556 224.008C414.956 223.768 415.396 223.648 415.876 223.648C416.292 223.648 416.692 223.76 417.076 223.984C417.476 224.208 417.804 224.536 418.06 224.968C418.316 225.384 418.444 225.888 418.444 226.48C418.444 227.072 418.316 227.584 418.06 228.016C417.804 228.432 417.476 228.752 417.076 228.976C416.692 229.2 416.292 229.312 415.876 229.312C415.396 229.312 414.956 229.2 414.556 228.976C414.156 228.736 413.836 228.408 413.596 227.992C413.356 227.56 413.236 227.056 413.236 226.48ZM424.881 213.28V232H428.529V213.28H424.881ZM442.654 220.96H438.934L435.406 229.792L437.278 229.816L433.702 220.96H429.718L434.494 231.112L431.806 237.28H435.454L442.654 220.96ZM467.021 224.776L462.413 214.36L457.853 224.776L454.541 215.2H449.741L457.013 232.984L462.413 222.856L467.837 232.984L475.109 215.2H470.285L467.021 224.776ZM480.325 232.24C481.733 232.24 482.925 231.968 483.901 231.424C484.893 230.88 485.677 230.064 486.253 228.976L483.013 228.184C482.741 228.664 482.373 229.024 481.909 229.264C481.461 229.504 480.917 229.624 480.277 229.624C479.717 229.624 479.245 229.504 478.861 229.264C478.477 229.008 478.189 228.64 477.997 228.16C477.805 227.68 477.709 227.104 477.709 226.432C477.725 225.696 477.821 225.088 477.997 224.608C478.189 224.112 478.469 223.744 478.837 223.504C479.205 223.264 479.661 223.144 480.205 223.144C480.637 223.144 481.013 223.24 481.333 223.432C481.653 223.624 481.901 223.896 482.077 224.248C482.253 224.6 482.341 225.016 482.341 225.496C482.341 225.608 482.309 225.752 482.245 225.928C482.197 226.088 482.133 226.224 482.053 226.336L482.917 225.232H476.101V227.248H486.181C486.213 227.136 486.229 227 486.229 226.84C486.229 226.664 486.229 226.488 486.229 226.312C486.229 225.128 485.997 224.12 485.533 223.288C485.069 222.456 484.397 221.824 483.517 221.392C482.637 220.944 481.557 220.72 480.277 220.72C478.997 220.72 477.885 220.952 476.941 221.416C476.013 221.88 475.301 222.544 474.805 223.408C474.309 224.272 474.061 225.296 474.061 226.48C474.061 227.648 474.317 228.664 474.829 229.528C475.341 230.392 476.061 231.064 476.989 231.544C477.933 232.008 479.045 232.24 480.325 232.24ZM492.067 213.28H488.443V232H492.067V213.28ZM501.091 226.48C501.091 225.232 500.835 224.184 500.323 223.336C499.827 222.488 499.179 221.84 498.379 221.392C497.595 220.944 496.747 220.72 495.835 220.72C494.923 220.72 494.107 220.952 493.387 221.416C492.667 221.88 492.099 222.544 491.683 223.408C491.267 224.256 491.059 225.28 491.059 226.48C491.059 227.664 491.267 228.688 491.683 229.552C492.099 230.416 492.667 231.08 493.387 231.544C494.107 232.008 494.923 232.24 495.835 232.24C496.747 232.24 497.595 232.016 498.379 231.568C499.179 231.12 499.827 230.472 500.323 229.624C500.835 228.76 501.091 227.712 501.091 226.48ZM497.275 226.48C497.275 227.056 497.155 227.56 496.915 227.992C496.675 228.408 496.355 228.736 495.955 228.976C495.555 229.2 495.115 229.312 494.635 229.312C494.219 229.312 493.811 229.2 493.411 228.976C493.027 228.752 492.707 228.432 492.451 228.016C492.195 227.584 492.067 227.072 492.067 226.48C492.067 225.888 492.195 225.384 492.451 224.968C492.707 224.536 493.027 224.208 493.411 223.984C493.811 223.76 494.219 223.648 494.635 223.648C495.115 223.648 495.555 223.768 495.955 224.008C496.355 224.232 496.675 224.56 496.915 224.992C497.155 225.408 497.275 225.904 497.275 226.48ZM513.475 228.76H522.355L522.091 225.664H513.763L513.475 228.76ZM517.867 221.368L520.243 226.816L520.099 227.848L522.115 232H526.723L517.867 214.144L509.035 232H513.619L515.707 227.68L515.515 226.792L517.867 221.368ZM531.723 237.28V220.96H528.099V237.28H531.723ZM540.747 226.48C540.747 225.184 540.491 224.104 539.979 223.24C539.483 222.36 538.835 221.696 538.035 221.248C537.251 220.8 536.403 220.576 535.491 220.576C534.531 220.576 533.699 220.824 532.995 221.32C532.307 221.8 531.779 222.48 531.411 223.36C531.043 224.24 530.859 225.28 530.859 226.48C530.859 227.664 531.043 228.704 531.411 229.6C531.779 230.48 532.307 231.168 532.995 231.664C533.699 232.144 534.531 232.384 535.491 232.384C536.403 232.384 537.251 232.16 538.035 231.712C538.835 231.264 539.483 230.6 539.979 229.72C540.491 228.84 540.747 227.76 540.747 226.48ZM536.931 226.48C536.931 227.056 536.811 227.544 536.571 227.944C536.331 228.344 536.011 228.648 535.611 228.856C535.211 229.064 534.771 229.168 534.291 229.168C533.875 229.168 533.467 229.072 533.067 228.88C532.683 228.672 532.363 228.368 532.107 227.968C531.851 227.568 531.723 227.072 531.723 226.48C531.723 225.888 531.851 225.392 532.107 224.992C532.363 224.592 532.683 224.296 533.067 224.104C533.467 223.896 533.875 223.792 534.291 223.792C534.771 223.792 535.211 223.896 535.611 224.104C536.011 224.312 536.331 224.616 536.571 225.016C536.811 225.416 536.931 225.904 536.931 226.48ZM546.536 237.28V220.96H542.912V237.28H546.536ZM555.56 226.48C555.56 225.184 555.304 224.104 554.792 223.24C554.296 222.36 553.648 221.696 552.848 221.248C552.064 220.8 551.216 220.576 550.304 220.576C549.344 220.576 548.512 220.824 547.808 221.32C547.12 221.8 546.592 222.48 546.224 223.36C545.856 224.24 545.672 225.28 545.672 226.48C545.672 227.664 545.856 228.704 546.224 229.6C546.592 230.48 547.12 231.168 547.808 231.664C548.512 232.144 549.344 232.384 550.304 232.384C551.216 232.384 552.064 232.16 552.848 231.712C553.648 231.264 554.296 230.6 554.792 229.72C555.304 228.84 555.56 227.76 555.56 226.48ZM551.744 226.48C551.744 227.056 551.624 227.544 551.384 227.944C551.144 228.344 550.824 228.648 550.424 228.856C550.024 229.064 549.584 229.168 549.104 229.168C548.688 229.168 548.28 229.072 547.88 228.88C547.496 228.672 547.176 228.368 546.92 227.968C546.664 227.568 546.536 227.072 546.536 226.48C546.536 225.888 546.664 225.392 546.92 224.992C547.176 224.592 547.496 224.296 547.88 224.104C548.28 223.896 548.688 223.792 549.104 223.792C549.584 223.792 550.024 223.896 550.424 224.104C550.824 224.312 551.144 224.616 551.384 225.016C551.624 225.416 551.744 225.904 551.744 226.48ZM558.348 227.992L556.836 230.392C557.332 230.776 557.868 231.128 558.444 231.448C559.02 231.752 559.644 231.992 560.316 232.168C561.004 232.36 561.748 232.456 562.548 232.456C563.86 232.456 564.876 232.16 565.596 231.568C566.332 230.96 566.7 230.064 566.7 228.88C566.7 228.192 566.548 227.64 566.244 227.224C565.956 226.808 565.564 226.464 565.068 226.192C564.588 225.92 564.06 225.68 563.484 225.472C562.94 225.264 562.476 225.096 562.092 224.968C561.724 224.824 561.436 224.672 561.228 224.512C561.036 224.352 560.94 224.152 560.94 223.912C560.94 223.704 561.02 223.536 561.18 223.408C561.356 223.28 561.612 223.216 561.948 223.216C562.444 223.216 562.988 223.36 563.58 223.648C564.172 223.92 564.7 224.272 565.164 224.704L566.46 222.352C566.028 222.032 565.564 221.752 565.068 221.512C564.588 221.272 564.068 221.08 563.508 220.936C562.964 220.792 562.372 220.72 561.732 220.72C560.932 220.72 560.22 220.84 559.596 221.08C558.988 221.32 558.5 221.672 558.132 222.136C557.78 222.6 557.604 223.168 557.604 223.84C557.604 224.544 557.756 225.12 558.06 225.568C558.364 226.016 558.748 226.376 559.212 226.648C559.692 226.904 560.196 227.128 560.724 227.32C561.316 227.496 561.78 227.664 562.116 227.824C562.468 227.984 562.716 228.152 562.86 228.328C563.004 228.488 563.076 228.688 563.076 228.928C563.076 229.184 562.988 229.392 562.812 229.552C562.636 229.712 562.364 229.792 561.996 229.792C561.74 229.792 561.436 229.744 561.084 229.648C560.732 229.536 560.324 229.352 559.86 229.096C559.412 228.824 558.908 228.456 558.348 227.992Z" fill="black" />
</svg>
''';
}
